Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1350)

Unified Diff: net/spdy/spdy_session.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/spdy_http_stream_spdy3_unittest.cc ('k') | net/spdy/spdy_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_session.h
diff --git a/net/spdy/spdy_session.h b/net/spdy/spdy_session.h
index f56187bb7cb900d590ca042a88f3a8e604d1d0f4..66a3acd62c42f108359bcafe22c20e73b3e9d426 100644
--- a/net/spdy/spdy_session.h
+++ b/net/spdy/spdy_session.h
@@ -160,13 +160,13 @@ class NET_EXPORT SpdySession : public base::RefCounted<SpdySession>,
// true when SSL is in use.
bool GetSSLCertRequestInfo(SSLCertRequestInfo* cert_request_info);
- // Returns the OriginBoundCertService used by this Socket, or NULL
- // Origin Bound Certs are not supported in this session.
- OriginBoundCertService* GetOriginBoundCertService() const;
+ // Returns the ServerBoundCertService used by this Socket, or NULL
+ // if server bound certs are not supported in this session.
+ ServerBoundCertService* GetServerBoundCertService() const;
- // Returns the type of the origin bound cert that was sent, or
+ // Returns the type of the domain bound cert that was sent, or
// CLIENT_CERT_INVALID_TYPE if none was sent.
- SSLClientCertType GetOriginBoundCertType() const;
+ SSLClientCertType GetDomainBoundCertType() const;
// Reset all static settings to initialized values. Used to init test suite.
static void ResetStaticSettingsToInit();
@@ -253,7 +253,7 @@ class NET_EXPORT SpdySession : public base::RefCounted<SpdySession>,
int GetLocalAddress(IPEndPoint* address) const;
// Returns true if a request for a resource in |origin| requires a
// SPDY CREDENTIAL frame to be sent first, with an origin bound certificate.
bool NeedsCredentials(const HostPortPair& origin) const;
// Adds |alias| to set of aliases associated with this session.
« no previous file with comments | « net/spdy/spdy_http_stream_spdy3_unittest.cc ('k') | net/spdy/spdy_session.cc » ('j') | no next file with comments »
@@ -253,7 +253,7 @@ class NET_EXPORT SpdySession : public base::RefCounted<SpdySession>,
int GetLocalAddress(IPEndPoint* address) const;
// Returns true if a request for a resource in |origin| requires a
- // SPDY CREDENTIAL frame to be sent first, with an origin bound certificate.
+ // SPDY CREDENTIAL frame to be sent first, with a domain bound certificate.
bool NeedsCredentials(const HostPortPair& origin) const;
// Adds |alias| to set of aliases associated with this session.

Powered by Google App Engine
This is Rietveld 408576698